Package 'zueriplots'

Title: showcase how to create ggplots with styling according to the city of Zurich
Description: Code for a variety of example plots, based on ggplot, styled according to the guidelines of the city of Zurich. Package does not export anything, exists for documentation purposes.
Authors: Alessandro Feller [aut, cre], Statistik Stadt Zürich [cph, fnd]
Maintainer: Alessandro Feller <[email protected]>
License: MIT + file LICENSE
Version: 0.2.1
Built: 2026-05-15 08:55:32 UTC
Source: https://github.com/StatistikStadtZuerich/zueriplots

Help Index